==> activity-center-api-1.3.9-20170308.150720-1-sources.jar: cn/com/duiba/activity/center/api/dto/activity/InsuranceUserInfoDto.java <==
package cn.com.duiba.activity.center.api.dto.activity;

import java.io.Serializable;
import java.util.Date;

/**
 * 
 *
 * <p>InsuranceHtmlEntity</p>
 * @author zhangka
 * @since 2017年1月17日 下午5:28:57
 */
public class InsuranceUserInfoDto implements Serializable {

	/**
	 * 
	 */
	private static final long serialVersionUID = 6321164548995220427L;

	/**
	 * 主键id
	 */
	private Long id;
	
	/**
	 * 兑吧用户id
	 */
	private Long consumerId;
	
	/**
	 * 用户姓名
	 */
	private String userName;
	
	/**
	 * 用户手机号
	 */
	private String userPhone;
	
	/**
	 * 用户身份证
	 */
	private String identification;
	
	/**
	 * 广告位id
	 */
	private Long advertId;
	
	/**
	 * 活动id
	 */
	private Long activityId;
	
	/**
	 * 广告计划id
	 */
	private Long advertPlanId;
	
	/**
	 * 广告媒体id
	 */
	private Long advertMediaId;
	
	/**
	 * 保险公司标记
	 */
	private String channelName;
	/**
	 * 创建时间
	 */
	private Date gmtCreate;
	
	/**
	 * 修改时间
	 */
	private Date gmtModified;

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public Long getConsumerId() {
		return consumerId;
	}

	public void setConsumerId(Long consumerId) {
		this.consumerId = consumerId;
	}

	public String getUserName() {
		return userName;
	}

	public void setUserName(String userName) {
		this.userName = userName;
	}

	public String getUserPhone() {
		return userPhone;
	}

	public void setUserPhone(String userPhone) {
		this.userPhone = userPhone;
	}

	public String getIdentification() {
		return identification;
	}

	public void setIdentification(String identification) {
		this.identification = identification;
	}

	public Long getAdvertId() {
		return advertId;
	}

	public void setAdvertId(Long advertId) {
		this.advertId = advertId;
	}

	public Long getActivityId() {
		return activityId;
	}

	public void setActivityId(Long activityId) {
		this.activityId = activityId;
	}

	public Long getAdvertPlanId() {
		return advertPlanId;
	}

	public void setAdvertPlanId(Long advertPlanId) {
		this.advertPlanId = advertPlanId;
	}

	public Long getAdvertMediaId() {
		return advertMediaId;
	}

	public void setAdvertMediaId(Long advertMediaId) {
		this.advertMediaId = advertMediaId;
	}

	public String getChannelName() {
		return channelName;
	}

	public void setChannelName(String channelName) {
		this.channelName = channelName;
	}

	public Date getGmtCreate() {
		return gmtCreate;
	}

	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}

	public Date getGmtModified() {
		return gmtModified;
	}

	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}
}

==> activity-center-api-3.6.11-20250108.063337-5-sources.jar: cn/com/duiba/activity/center/api/dto/activity/InsuranceUserInfoDto.java <==
package cn.com.duiba.activity.center.api.dto.activity;

import java.io.Serializable;
import java.util.Date;

/**
 * 
 *
 * <p>InsuranceHtmlEntity</p>
 * @author zhangka
 * @since 2017年1月17日 下午5:28:57
 */
public class InsuranceUserInfoDto implements Serializable {

	/**
	 * 
	 */
	private static final long serialVersionUID = 6321164548995220427L;

	/**
	 * 主键id
	 */
	private Long id;
	
	/**
	 * 兑吧用户id
	 */
	private Long consumerId;
	
	/**
	 * 用户姓名
	 */
	private String userName;
	
	/**
	 * 用户手机号
	 */
	private String userPhone;
	
	/**
	 * 用户身份证
	 */
	private String identification;
	
	/**
	 * 广告位id
	 */
	private Long advertId;
	
	/**
	 * 活动id
	 */
	private Long activityId;
	
	/**
	 * 广告计划id
	 */
	private Long advertPlanId;
	
	/**
	 * 广告媒体id
	 */
	private Long advertMediaId;
	
	/**
	 * 保险公司标记
	 */
	private String channelName;
	/**
	 * 创建时间
	 */
	private Date gmtCreate;
	
	/**
	 * 修改时间
	 */
	private Date gmtModified;
	
	/**
	 * 其他信息(json格式存储)
	 */
	private String info;

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public Long getConsumerId() {
		return consumerId;
	}

	public void setConsumerId(Long consumerId) {
		this.consumerId = consumerId;
	}

	public String getUserName() {
		return userName;
	}

	public void setUserName(String userName) {
		this.userName = userName;
	}

	public String getUserPhone() {
		return userPhone;
	}

	public void setUserPhone(String userPhone) {
		this.userPhone = userPhone;
	}

	public String getIdentification() {
		return identification;
	}

	public void setIdentification(String identification) {
		this.identification = identification;
	}

	public Long getAdvertId() {
		return advertId;
	}

	public void setAdvertId(Long advertId) {
		this.advertId = advertId;
	}

	public Long getActivityId() {
		return activityId;
	}

	public void setActivityId(Long activityId) {
		this.activityId = activityId;
	}

	public Long getAdvertPlanId() {
		return advertPlanId;
	}

	public void setAdvertPlanId(Long advertPlanId) {
		this.advertPlanId = advertPlanId;
	}

	public Long getAdvertMediaId() {
		return advertMediaId;
	}

	public void setAdvertMediaId(Long advertMediaId) {
		this.advertMediaId = advertMediaId;
	}

	public String getChannelName() {
		return channelName;
	}

	public void setChannelName(String channelName) {
		this.channelName = channelName;
	}

	public Date getGmtCreate() {
		return gmtCreate;
	}

	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}

	public Date getGmtModified() {
		return gmtModified;
	}

	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}

    public String getInfo() {
        return info;
    }

    public void setInfo(String info) {
        this.info = info;
    }
}
